@@ -436,7 +436,7 @@ function (solu)
     lo <- length(solu)
     recon <- t(solu[[1]]$v)
     for (k in 2:lo) {
-        recon <- recon %o% t(essreconf[[k]]$v)
+        recon <- recon %o% t(solu[[k]]$v)
     }
     reconf <- CONTRACTION(recon, solu[[lo]]$coremat, Xwiz = (1:(lo - 
         1)) * 2, zwiX = 1:(lo - 1))
@@ -2013,7 +2013,7 @@ function (A)
     Powmat(A, -1)
 }
 "IterMV" <-
-function (n = 10, dat = X, Mm = c(1, 3), Vm = c(2, 3),
+function (n = 10, dat, Mm = c(1, 3), Vm = c(2, 3),
     fFUN = mean, usetren = FALSE, tren = function(x) smooth.spline(as.vector(x),
         df = 5)$y, rsd = TRUE)
 {
@@ -2039,7 +2039,7 @@ function (n = 10, dat = X, Mm = c(1, 3), Vm = c(2, 3),
     return(dat)
 }
 "Multcent" <-
-function (dat = X, bi = c(1, 2), by = 3, centre = mean,
+function (dat, bi = c(1, 2), by = 3, centre = mean,
     centrebyBA = c(TRUE, FALSE), scalebyBA = c(TRUE, FALSE))
 {
     if (centrebyBA[1]) {
